@@ -2,15 +2,18 @@
 #this repository contains the full copyright notices and license terms.
 {
     'name': 'Analytic Sale',
+    'name_bg_BG': 'Аналитична продажба',
     'name_de_DE': 'Kostenstellen Verkauf',
     'name_es_CO': 'Ventas Analíticas',
     'name_es_ES': 'Venta analítica',
     'name_fr_FR': 'Vente analytique',
-    'version': '1.8.0',
+    'version': '2.0.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
     'description': '''Add analytic account on sale lines.
+''',
+    'description_bg_BG': '''Добавя аналитична сметка към редове от продажба
 ''',
     'description_de_DE': '''Fügt Kostenstellen zu den Verkaufspositionen hinzu
 ''',
@@ -27,6 +30,7 @@
         'sale.xml',
     ],
     'translation': [
+        'bg_BG.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
